==> ejc-bid-impl-3.0.0-20231023.102317-387-sources.jar: com/ejianc/business/bid/bean/BiddingFileReviewZiEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 招标文件评审子表
 * 
 * @author generator
 * 
 */
 @TableName("t_bid_bidding_file_review_zi")
public class BiddingFileReviewZiEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="ry_id")
    private Long ryId; // 人员id
    @TableField(value="ry_name")
    private String ryName; // 人员名字
    @TableField(value="gw_id")
    private Long gwId; // 岗位id
    @TableField(value="gw")
    private String gw; // 岗位
    @TableField(value="ssdw")
    private String ssdw; // 所属单位
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="sfgs")
    private Integer sfgs; // 是否公式（0：否，1：是）
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getRyId() {
        return ryId;
    }

    public void setRyId(Long ryId) {
        this.ryId = ryId;
    }
    public String getRyName() {
        return ryName;
    }

    public void setRyName(String ryName) {
        this.ryName = ryName;
    }
    public Long getGwId() {
        return gwId;
    }

    public void setGwId(Long gwId) {
        this.gwId = gwId;
    }
    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }
    public String getSsdw() {
        return ssdw;
    }

    public void setSsdw(String ssdw) {
        this.ssdw = ssdw;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSfgs() {
        return sfgs;
    }

    public void setSfgs(Integer sfgs) {
        this.sfgs = sfgs;
    }
    
}

==> ejc-bid-impl-3.0.0-20240105.020743-399-sources.jar: com/ejianc/business/bid/bean/BiddingFileReviewZiEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 招标文件评审子表
 * 
 * @author generator
 * 
 */
 @TableName("t_bid_bidding_file_review_zi")
public class BiddingFileReviewZiEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="ry_id")
    private Long ryId; // 人员id
    @TableField(value="ry_name")
    private String ryName; // 人员名字
    @TableField(value="gw_id")
    private Long gwId; // 岗位id
    @TableField(value="gw")
    private String gw; // 岗位
    @TableField(value="ssdw")
    private String ssdw; // 所属单位
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="sfgs")
    private Integer sfgs; // 是否公式（0：否，1：是）
    @TableField(value="constructor_id_card")
    private String constructorIdCard; // 建造师身份证号


    public String getConstructorIdCard() {
        return constructorIdCard;
    }

    public void setConstructorIdCard(String constructorIdCard) {
        this.constructorIdCard = constructorIdCard;
    }
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getRyId() {
        return ryId;
    }

    public void setRyId(Long ryId) {
        this.ryId = ryId;
    }
    public String getRyName() {
        return ryName;
    }

    public void setRyName(String ryName) {
        this.ryName = ryName;
    }
    public Long getGwId() {
        return gwId;
    }

    public void setGwId(Long gwId) {
        this.gwId = gwId;
    }
    public String getGw() {
        return gw;
    }

    public void setGw(String gw) {
        this.gw = gw;
    }
    public String getSsdw() {
        return ssdw;
    }

    public void setSsdw(String ssdw) {
        this.ssdw = ssdw;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSfgs() {
        return sfgs;
    }

    public void setSfgs(Integer sfgs) {
        this.sfgs = sfgs;
    }
    
}
